@@ -59,7 +59,7 @@ class ParsingException : public std::exception {
 
 // ---------------------------------------------------------------------------
 
-static void usage() {
+[[noreturn]] static void usage() {
     std::cerr << "usage: projsync " << std::endl;
     std::cerr << "          [--endpoint URL]" << std::endl;
     std::cerr << "          [--local-geojson-file FILENAME]" << std::endl;
@@ -90,10 +90,10 @@ static std::vector<double> get_bbox(const json &j) {
     } else {
         for (const auto &obj : j) {
             if (obj.is_array()) {
-                const auto subres = get_bbox(obj);
+                auto subres = get_bbox(obj);
                 if (subres.size() == 4) {
                     if (res.empty()) {
-                        res = subres;
+                        res = std::move(subres);
                     } else {
                         res[0] = std::min(res[0], subres[0]);
                         res[1] = std::min(res[1], subres[1]);
@@ -242,7 +242,7 @@ int main(int argc, char *argv[]) {
         }
 
         // This is used by projsync() to determine where to write files.
-        pj_context_set_user_writable_directory(ctx, targetDir);
+        proj_context_set_user_writable_directory(ctx, targetDir.c_str(), true);
     }
 
     if (!endpoint.empty() && endpoint.back() == '/') {
@@ -289,7 +289,7 @@ int main(int argc, char *argv[]) {
     file.reset();
 
     if (listFiles) {
-        std::cout << "filename,source_id,area_of_use,file_size" << std::endl;
+        std::cout << "filename,area_of_use,source_id,file_size" << std::endl;
     }
 
     std::string proj_data_version_str;
@@ -362,7 +362,7 @@ int main(int argc, char *argv[]) {
                                           << " as it is only useful starting "
                                              "with PROJ-data "
                                           << version_added
-                                          << " and we are targetting "
+                                          << " and we are targeting "
                                           << proj_data_version_str << std::endl;
                             }
                             continue;
@@ -390,7 +390,7 @@ int main(int argc, char *argv[]) {
                                           << " as it is no longer useful "
                                              "starting with PROJ-data "
                                           << version_removed
-                                          << " and we are targetting "
+                                          << " and we are targeting "
                                           << proj_data_version_str << std::endl;
                             }
                             continue;
@@ -492,13 +492,13 @@ int main(int argc, char *argv[]) {
                         bool foundPlus180 = false;
                         for (const auto &obj : j_coordinates) {
                             if (obj.is_array()) {
-                                const auto tmp = get_bbox(obj);
+                                auto tmp = get_bbox(obj);
                                 if (tmp.size() == 4) {
                                     if (tmp[0] == -180)
                                         foundMinus180 = true;
                                     else if (tmp[2] == 180)
                                         foundPlus180 = true;
-                                    grid_bboxes.push_back(tmp);
+                                    grid_bboxes.push_back(std::move(tmp));
                                 }
                             }
                         }
@@ -565,10 +565,11 @@ int main(int argc, char *argv[]) {
                     continue;
                 }
 
-                const std::string resource_url(endpoint + '/' + name);
+                std::string resource_url(
+                    std::string(endpoint).append("/").append(name));
                 if (proj_is_download_needed(ctx, resource_url.c_str(), false)) {
                     total_size_to_download += file_size;
-                    to_download.push_back(resource_url);
+                    to_download.push_back(std::move(resource_url));
                 } else {
                     if (!quiet) {
                         std::cout << resource_url << " already downloaded."
