@@ -32,6 +32,7 @@
 
 #include "proj/internal/internal.hpp"
 
+#include <cmath>
 #include <cstdint>
 #include <cstring>
 #ifdef _MSC_VER
@@ -240,7 +241,17 @@ bool ends_with(const std::string &str, const std::string &suffix) noexcept {
 // ---------------------------------------------------------------------------
 
 double c_locale_stod(const std::string &s) {
+    bool success;
+    double val = c_locale_stod(s, success);
+    if (!success) {
+        throw std::invalid_argument("non double value");
+    }
+    return val;
+}
 
+double c_locale_stod(const std::string &s, bool &success) {
+
+    success = true;
     const auto s_size = s.size();
     // Fast path
     if (s_size > 0 && s_size < 15) {
@@ -277,7 +288,8 @@ double c_locale_stod(const std::string &s) {
     double d;
     iss >> d;
     if (!iss.eof() || iss.fail()) {
-        throw std::invalid_argument("non double value");
+        success = false;
+        d = 0;
     }
     return d;
 }
@@ -384,6 +396,17 @@ std::string concat(const char *a, const std::string &b, const char *c) {
 
 // ---------------------------------------------------------------------------
 
+// Avoid rounding issues due to year -> second (SI unit) -> year roundtrips
+double getRoundedEpochInDecimalYear(double year) {
+    // Try to see if the value is close to xxxx.yyy decimal year.
+    if (std::fabs(1000 * year - std::round(1000 * year)) <= 1e-3) {
+        year = std::round(1000 * year) / 1000.0;
+    }
+    return year;
+}
+
+// ---------------------------------------------------------------------------
+
 } // namespace internal
 
 NS_PROJ_END
