@@ -78,14 +78,14 @@ struct Citation::Private {
 // ---------------------------------------------------------------------------
 
 //! @cond Doxygen_Suppress
-Citation::Citation() : d(internal::make_unique<Private>()) {}
+Citation::Citation() : d(std::make_unique<Private>()) {}
 //! @endcond
 
 // ---------------------------------------------------------------------------
 
 /** \brief Constructs a citation by its title. */
 Citation::Citation(const std::string &titleIn)
-    : d(internal::make_unique<Private>()) {
+    : d(std::make_unique<Private>()) {
     d->title = titleIn;
 }
 
@@ -93,7 +93,7 @@ Citation::Citation(const std::string &titleIn)
 
 //! @cond Doxygen_Suppress
 Citation::Citation(const Citation &other)
-    : d(internal::make_unique<Private>(*(other.d))) {}
+    : d(std::make_unique<Private>(*(other.d))) {}
 
 // ---------------------------------------------------------------------------
 
@@ -124,7 +124,7 @@ struct GeographicExtent::Private {};
 
 // ---------------------------------------------------------------------------
 
-GeographicExtent::GeographicExtent() : d(internal::make_unique<Private>()) {}
+GeographicExtent::GeographicExtent() : d(std::make_unique<Private>()) {}
 
 // ---------------------------------------------------------------------------
 
@@ -155,7 +155,7 @@ struct GeographicBoundingBox::Private {
 GeographicBoundingBox::GeographicBoundingBox(double west, double south,
                                              double east, double north)
     : GeographicExtent(),
-      d(internal::make_unique<Private>(west, south, east, north)) {}
+      d(std::make_unique<Private>(west, south, east, north)) {}
 
 // ---------------------------------------------------------------------------
 
@@ -238,6 +238,27 @@ GeographicBoundingBoxNNPtr GeographicBoundingBox::create(double west,
         throw InvalidValueTypeException(
             "GeographicBoundingBox::create() does not accept NaN values");
     }
+    if (south > north) {
+        throw InvalidValueTypeException(
+            "GeographicBoundingBox::create() does not accept south > north");
+    }
+    // Avoid creating a degenerate bounding box if reduced to a point or a line
+    if (west == east) {
+        if (west > -180)
+            west =
+                std::nextafter(west, -std::numeric_limits<double>::infinity());
+        if (east < 180)
+            east =
+                std::nextafter(east, std::numeric_limits<double>::infinity());
+    }
+    if (south == north) {
+        if (south > -90)
+            south =
+                std::nextafter(south, -std::numeric_limits<double>::infinity());
+        if (north < 90)
+            north =
+                std::nextafter(north, std::numeric_limits<double>::infinity());
+    }
     return GeographicBoundingBox::nn_make_shared<GeographicBoundingBox>(
         west, south, east, north);
 }
@@ -322,14 +343,21 @@ bool GeographicBoundingBox::Private::intersects(const Private &other) const {
     const double oN = other.north_;
     const double oS = other.south_;
 
+    // Check intersection along the latitude axis
     if (N < oS || S > oN) {
         return false;
     }
 
+    // Check world coverage of this bbox, and other bbox overlapping
+    // antimeridian (e.g. oW=175 and oE=-175)
+    // Check oW > oE written for symmetry with the intersection() method.
     if (W == -180.0 && E == 180.0 && oW > oE) {
         return true;
     }
 
+    // Check world coverage of other bbox, and this bbox overlapping
+    // antimeridian (e.g. W=175 and E=-175)
+    // Check W > E written for symmetry with the intersection() method.
     if (oW == -180.0 && oE == 180.0 && W > E) {
         return true;
     }
@@ -353,7 +381,7 @@ bool GeographicBoundingBox::Private::intersects(const Private &other) const {
         return intersects(Private(oW, oS, 180.0, oN)) ||
                intersects(Private(-180.0, oS, oE, oN));
 
-        // No: crossing antimerian
+        // No: crossing antimeridian
     } else {
         if (oW <= oE) {
             return other.intersects(*this);
@@ -402,18 +430,23 @@ GeographicBoundingBox::Private::intersection(const Private &otherExtent) const {
     const double oN = otherExtent.north_;
     const double oS = otherExtent.south_;
 
+    // Check intersection along the latitude axis
     if (N < oS || S > oN) {
         return nullptr;
     }
 
+    // Check world coverage of this bbox, and other bbox overlapping
+    // antimeridian (e.g. oW=175 and oE=-175)
     if (W == -180.0 && E == 180.0 && oW > oE) {
-        return internal::make_unique<Private>(oW, std::max(S, oS), oE,
-                                              std::min(N, oN));
+        return std::make_unique<Private>(oW, std::max(S, oS), oE,
+                                         std::min(N, oN));
     }
 
+    // Check world coverage of other bbox, and this bbox overlapping
+    // antimeridian (e.g. W=175 and E=-175)
     if (oW == -180.0 && oE == 180.0 && W > E) {
-        return internal::make_unique<Private>(W, std::max(S, oS), E,
-                                              std::min(N, oN));
+        return std::make_unique<Private>(W, std::max(S, oS), E,
+                                         std::min(N, oN));
     }
 
     // Normal bounding box ?
@@ -422,8 +455,8 @@ GeographicBoundingBox::Private::intersection(const Private &otherExtent) const {
             const double resW = std::max(W, oW);
             const double resE = std::min(E, oE);
             if (resW < resE) {
-                return internal::make_unique<Private>(resW, std::max(S, oS),
-                                                      resE, std::min(N, oN));
+                return std::make_unique<Private>(resW, std::max(S, oS), resE,
+                                                 std::min(N, oN));
             }
             return nullptr;
         }
@@ -448,14 +481,14 @@ GeographicBoundingBox::Private::intersection(const Private &otherExtent) const {
             return inter1;
         }
         return inter2;
-        // No: crossing antimerian
+        // No: crossing antimeridian
     } else {
         if (oW <= oE) {
             return otherExtent.intersection(*this);
         }
 
-        return internal::make_unique<Private>(std::max(W, oW), std::max(S, oS),
-                                              std::min(E, oE), std::min(N, oN));
+        return std::make_unique<Private>(std::max(W, oW), std::max(S, oS),
+                                         std::min(E, oE), std::min(N, oN));
     }
 }
 //! @endcond
@@ -478,7 +511,7 @@ struct VerticalExtent::Private {
 
 VerticalExtent::VerticalExtent(double minimumIn, double maximumIn,
                                const common::UnitOfMeasureNNPtr &unitIn)
-    : d(internal::make_unique<Private>(minimumIn, maximumIn, unitIn)) {}
+    : d(std::make_unique<Private>(minimumIn, maximumIn, unitIn)) {}
 
 // ---------------------------------------------------------------------------
 
@@ -575,7 +608,7 @@ struct TemporalExtent::Private {
 
 TemporalExtent::TemporalExtent(const std::string &startIn,
                                const std::string &stopIn)
-    : d(internal::make_unique<Private>(startIn, stopIn)) {}
+    : d(std::make_unique<Private>(startIn, stopIn)) {}
 
 // ---------------------------------------------------------------------------
 
@@ -651,12 +684,11 @@ struct Extent::Private {
 // ---------------------------------------------------------------------------
 
 //! @cond Doxygen_Suppress
-Extent::Extent() : d(internal::make_unique<Private>()) {}
+Extent::Extent() : d(std::make_unique<Private>()) {}
 
 // ---------------------------------------------------------------------------
 
-Extent::Extent(const Extent &other)
-    : d(internal::make_unique<Private>(*other.d)) {}
+Extent::Extent(const Extent &other) : d(std::make_unique<Private>(*other.d)) {}
 
 // ---------------------------------------------------------------------------
 
@@ -916,8 +948,8 @@ void Identifier::Private::setProperties(
                                                     AUTHORITY_KEY);
                 }
             } else {
-                if (auto citation =
-                        dynamic_cast<const Citation *>(pVal->get())) {
+                auto citation = dynamic_cast<const Citation *>(pVal->get());
+                if (citation) {
                     authority_ = *citation;
                 } else {
                     throw InvalidValueTypeException("Invalid value type for " +
@@ -958,7 +990,7 @@ void Identifier::Private::setProperties(
 
 Identifier::Identifier(const std::string &codeIn,
                        const util::PropertyMap &properties)
-    : d(internal::make_unique<Private>(codeIn, properties)) {}
+    : d(std::make_unique<Private>(codeIn, properties)) {}
 
 // ---------------------------------------------------------------------------
 
@@ -966,12 +998,12 @@ Identifier::Identifier(const std::string &codeIn,
 
 // ---------------------------------------------------------------------------
 
-Identifier::Identifier() : d(internal::make_unique<Private>()) {}
+Identifier::Identifier() : d(std::make_unique<Private>()) {}
 
 // ---------------------------------------------------------------------------
 
 Identifier::Identifier(const Identifier &other)
-    : d(internal::make_unique<Private>(*(other.d))) {}
+    : d(std::make_unique<Private>(*(other.d))) {}
 
 // ---------------------------------------------------------------------------
 
@@ -1181,6 +1213,14 @@ static bool isIgnoredChar(char ch) {
 
 // ---------------------------------------------------------------------------
 
+//! @cond Doxygen_Suppress
+static char lower(char ch) {
+    return ch >= 'A' && ch <= 'Z' ? ch - 'A' + 'a' : ch;
+}
+//! @endcond
+
+// ---------------------------------------------------------------------------
+
 //! @cond Doxygen_Suppress
 static const struct utf8_to_lower {
     const char *utf8;
@@ -1216,21 +1256,94 @@ static const struct utf8_to_lower *get_ascii_replacement(const char *c_str) {
 // ---------------------------------------------------------------------------
 
 //! @cond Doxygen_Suppress
-std::string Identifier::canonicalizeName(const std::string &str) {
+
+/** Checks if needle is a substring of c_str.
+ *
+ * e.g matchesLowerCase("JavaScript", "java") returns true
+ */
+static bool matchesLowerCase(const char *c_str, const char *needle) {
+    size_t i = 0;
+    for (; c_str[i] && needle[i]; ++i) {
+        if (lower(c_str[i]) != lower(needle[i])) {
+            return false;
+        }
+    }
+    return needle[i] == 0;
+}
+//! @endcond
+
+// ---------------------------------------------------------------------------
+
+//! @cond Doxygen_Suppress
+
+static inline bool isdigit(char ch) { return ch >= '0' && ch <= '9'; }
+//! @endcond
+
+// ---------------------------------------------------------------------------
+
+//! @cond Doxygen_Suppress
+std::string Identifier::canonicalizeName(const std::string &str,
+                                         bool biggerDifferencesAllowed) {
     std::string res;
     const char *c_str = str.c_str();
     for (size_t i = 0; c_str[i] != 0; ++i) {
-        const auto ch = c_str[i];
+        const auto ch = lower(c_str[i]);
         if (ch == ' ' && c_str[i + 1] == '+' && c_str[i + 2] == ' ') {
             i += 2;
             continue;
         }
-        if (ch == '1' && !res.empty() &&
-            !(res.back() >= '0' && res.back() <= '9') && c_str[i + 1] == '9' &&
-            c_str[i + 2] >= '0' && c_str[i + 2] <= '9') {
+
+        // Canonicalize "19dd" (where d is a digit) as "dd"
+        if (ch == '1' && !res.empty() && !isdigit(res.back()) &&
+            c_str[i + 1] == '9' && isdigit(c_str[i + 2]) &&
+            isdigit(c_str[i + 3])) {
             ++i;
             continue;
         }
+
+        if (biggerDifferencesAllowed) {
+
+            const auto skipSubstring = [](char l_ch, const char *l_str,
+                                          size_t &idx, const char *substr) {
+                if (l_ch == substr[0] && idx > 0 &&
+                    isIgnoredChar(l_str[idx - 1]) &&
+                    matchesLowerCase(l_str + idx, substr)) {
+                    idx += strlen(substr) - 1;
+                    return true;
+                }
+                return false;
+            };
+
+            // Skip "zone" or "height" if preceding character is a space
+            if (skipSubstring(ch, c_str, i, "zone") ||
+                skipSubstring(ch, c_str, i, "height")) {
+                continue;
+            }
+
+            // Replace a substring by its first character if preceding character
+            // is a space or a digit
+            const auto replaceByFirstChar = [](char l_ch, const char *l_str,
+                                               size_t &idx, const char *substr,
+                                               std::string &l_res) {
+                if (l_ch == substr[0] && idx > 0 &&
+                    (isIgnoredChar(l_str[idx - 1]) ||
+                     isdigit(l_str[idx - 1])) &&
+                    matchesLowerCase(l_str + idx, substr)) {
+                    l_res.push_back(l_ch);
+                    idx += strlen(substr) - 1;
+                    return true;
+                }
+                return false;
+            };
+
+            // Replace "north" or "south" by its first character if preceding
+            // character is a space or a digit
+            if (replaceByFirstChar(ch, c_str, i, "north", res) ||
+                replaceByFirstChar(ch, c_str, i, "south", res)) {
+                continue;
+            }
+        }
+
         if (static_cast<unsigned char>(ch) > 127) {
             const auto *replacement = get_ascii_replacement(c_str + i);
             if (replacement) {
@@ -1240,7 +1353,7 @@ std::string Identifier::canonicalizeName(const std::string &str) {
             }
         }
         if (!isIgnoredChar(ch)) {
-            res.push_back(static_cast<char>(::tolower(ch)));
+            res.push_back(ch);
         }
     }
     return res;
@@ -1253,15 +1366,22 @@ std::string Identifier::canonicalizeName(const std::string &str) {
  *
  * Two names are equivalent by removing any space, underscore, dash, slash,
  * { or } character from them, and comparing in a case insensitive way.
+ *
+ * @param a first string
+ * @param b second string
+ * @param biggerDifferencesAllowed if true, "height" and "zone" words are
+ * ignored, and "north" is shortened as "n" and "south" as "n".
+ * @since 9.6
  */
-bool Identifier::isEquivalentName(const char *a, const char *b) noexcept {
+bool Identifier::isEquivalentName(const char *a, const char *b,
+                                  bool biggerDifferencesAllowed) noexcept {
     size_t i = 0;
     size_t j = 0;
     char lastValidA = 0;
     char lastValidB = 0;
     while (a[i] != 0 || b[j] != 0) {
-        char aCh = a[i];
-        char bCh = b[j];
+        char aCh = lower(a[i]);
+        char bCh = lower(b[j]);
         if (aCh == ' ' && a[i + 1] == '+' && a[i + 2] == ' ' && a[i + 3] != 0) {
             i += 3;
             continue;
@@ -1278,18 +1398,69 @@ bool Identifier::isEquivalentName(const char *a, const char *b) noexcept {
             ++j;
             continue;
         }
-        if (aCh == '1' && !(lastValidA >= '0' && lastValidA <= '9') &&
-            a[i + 1] == '9' && a[i + 2] >= '0' && a[i + 2] <= '9') {
+
+        // Canonicalize "19dd" (where d is a digit) as "dd"
+        if (aCh == '1' && !isdigit(lastValidA) && a[i + 1] == '9' &&
+            isdigit(a[i + 2]) && isdigit(a[i + 3])) {
             i += 2;
             lastValidA = '9';
             continue;
         }
-        if (bCh == '1' && !(lastValidB >= '0' && lastValidB <= '9') &&
-            b[j + 1] == '9' && b[j + 2] >= '0' && b[j + 2] <= '9') {
+        if (bCh == '1' && !isdigit(lastValidB) && b[j + 1] == '9' &&
+            isdigit(b[j + 2]) && isdigit(b[j + 3])) {
             j += 2;
             lastValidB = '9';
             continue;
         }
+
+        if (biggerDifferencesAllowed) {
+            // Skip a substring if preceding character is a space
+            const auto skipSubString = [](char ch, const char *str, size_t &idx,
+                                          const char *substr) {
+                if (ch == substr[0] && idx > 0 && isIgnoredChar(str[idx - 1]) &&
+                    matchesLowerCase(str + idx, substr)) {
+                    idx += strlen(substr);
+                    return true;
+                }
+                return false;
+            };
+
+            bool skip = false;
+            if (skipSubString(aCh, a, i, "zone"))
+                skip = true;
+            if (skipSubString(bCh, b, j, "zone"))
+                skip = true;
+            if (skip)
+                continue;
+
+            if (skipSubString(aCh, a, i, "height"))
+                skip = true;
+            if (skipSubString(bCh, b, j, "height"))
+                skip = true;
+            if (skip)
+                continue;
+
+            // Replace a substring by its first character if preceding character
+            // is a space or a digit
+            const auto replaceByFirstChar = [](char ch, const char *str,
+                                               size_t &idx,
+                                               const char *substr) {
+                if (ch == substr[0] && idx > 0 &&
+                    (isIgnoredChar(str[idx - 1]) || isdigit(str[idx - 1])) &&
+                    matchesLowerCase(str + idx, substr)) {
+                    idx += strlen(substr) - 1;
+                    return true;
+                }
+                return false;
+            };
+
+            if (!replaceByFirstChar(aCh, a, i, "north"))
+                replaceByFirstChar(aCh, a, i, "south");
+
+            if (!replaceByFirstChar(bCh, b, j, "north"))
+                replaceByFirstChar(bCh, b, j, "south");
+        }
+
         if (static_cast<unsigned char>(aCh) > 127) {
             const auto *replacement = get_ascii_replacement(a + i);
             if (replacement) {
@@ -1304,8 +1475,7 @@ bool Identifier::isEquivalentName(const char *a, const char *b) noexcept {
                 j += strlen(replacement->utf8) - 1;
             }
         }
-        if ((aCh == 0 && bCh != 0) || (aCh != 0 && bCh == 0) ||
-            ::tolower(aCh) != ::tolower(bCh)) {
+        if (aCh != bCh) {
             return false;
         }
         lastValidA = aCh;
@@ -1320,6 +1490,17 @@ bool Identifier::isEquivalentName(const char *a, const char *b) noexcept {
 
 // ---------------------------------------------------------------------------
 
+/** \brief Returns whether two names are considered equivalent.
+ *
+ * Two names are equivalent by removing any space, underscore, dash, slash,
+ * { or } character from them, and comparing in a case insensitive way.
+ */
+bool Identifier::isEquivalentName(const char *a, const char *b) noexcept {
+    return isEquivalentName(a, b, /* biggerDifferencesAllowed = */ true);
+}
+
+// ---------------------------------------------------------------------------
+
 //! @cond Doxygen_Suppress
 struct PositionalAccuracy::Private {
     std::string value_{};
@@ -1329,7 +1510,7 @@ struct PositionalAccuracy::Private {
 // ---------------------------------------------------------------------------
 
 PositionalAccuracy::PositionalAccuracy(const std::string &valueIn)
-    : d(internal::make_unique<Private>()) {
+    : d(std::make_unique<Private>()) {
     d->value_ = valueIn;
 }
 
