@@ -114,6 +114,19 @@ PJ *proj_destroy(PJ *P) {
 PJconsts::PJconsts() : destructor(pj_default_destructor) {}
 /*****************************************************************************/
 
+/*****************************************************************************/
+/*              void PJconsts::copyStateFrom(const PJconsts& other)          */
+/*****************************************************************************/
+
+void PJconsts::copyStateFrom(const PJconsts &other) {
+    over = other.over;
+    errorIfBestTransformationNotAvailable =
+        other.errorIfBestTransformationNotAvailable;
+    warnIfBestTransformationNotAvailable =
+        other.warnIfBestTransformationNotAvailable;
+    skipNonInstantiable = other.skipNonInstantiable;
+}
+
 /*****************************************************************************/
 PJ *pj_new() {
     /*****************************************************************************/
@@ -166,6 +179,8 @@ PJ *pj_default_destructor(PJ *P, int errlev) { /* Destructor */
     proj_destroy(P->hgridshift);
     proj_destroy(P->vgridshift);
 
+    proj_destroy(P->cached_op_for_proj_factors);
+
     free(static_cast<struct pj_opaque *>(P->opaque));
     delete P;
     return nullptr;
