@@ -214,6 +214,9 @@
 #define EPSG_NAME_METHOD_ORTHOGRAPHIC "Orthographic"
 #define EPSG_CODE_METHOD_ORTHOGRAPHIC 9840
 
+#define EPSG_NAME_METHOD_LOCAL_ORTHOGRAPHIC "Local Orthographic"
+#define EPSG_CODE_METHOD_LOCAL_ORTHOGRAPHIC 1130
+
 #define PROJ_WKT2_NAME_ORTHOGRAPHIC_SPHERICAL "Orthographic (Spherical)"
 
 #define PROJ_WKT2_NAME_METHOD_PATTERSON "Patterson"
@@ -311,17 +314,29 @@
     "Longitude of projection centre"
 #define EPSG_CODE_PARAMETER_LONGITUDE_PROJECTION_CENTRE 8812
 
+// Before EPSG 11.015
 #define EPSG_NAME_PARAMETER_AZIMUTH_INITIAL_LINE "Azimuth of initial line"
 #define EPSG_CODE_PARAMETER_AZIMUTH_INITIAL_LINE 8813
 
+// Since EPSG 11.015
+#define EPSG_NAME_PARAMETER_AZIMUTH_PROJECTION_CENTRE                          \
+    "Azimuth at projection centre"
+#define EPSG_CODE_PARAMETER_AZIMUTH_PROJECTION_CENTRE 8813
+
 #define EPSG_NAME_PARAMETER_ANGLE_RECTIFIED_TO_SKEW_GRID                       \
     "Angle from Rectified to Skew Grid"
 #define EPSG_CODE_PARAMETER_ANGLE_RECTIFIED_TO_SKEW_GRID 8814
 
+// Before EPSG 11.015
 #define EPSG_NAME_PARAMETER_SCALE_FACTOR_INITIAL_LINE                          \
     "Scale factor on initial line"
 #define EPSG_CODE_PARAMETER_SCALE_FACTOR_INITIAL_LINE 8815
 
+// Since EPSG 11.015
+#define EPSG_NAME_PARAMETER_SCALE_FACTOR_PROJECTION_CENTRE                     \
+    "Scale factor at projection centre"
+#define EPSG_CODE_PARAMETER_SCALE_FACTOR_PROJECTION_CENTRE 8815
+
 #define EPSG_NAME_PARAMETER_EASTING_PROJECTION_CENTRE                          \
     "Easting at projection centre"
 #define EPSG_CODE_PARAMETER_EASTING_PROJECTION_CENTRE 8816
@@ -395,10 +410,22 @@
     "Coordinate Frame rotation (geocentric domain)"
 #define EPSG_CODE_METHOD_COORDINATE_FRAME_GEOCENTRIC 1032
 
+#define EPSG_NAME_METHOD_COORDINATE_FRAME_FULL_MATRIX_GEOCENTRIC               \
+    "Coordinate Frame rotation full matrix (geocen)"
+#define EPSG_CODE_METHOD_COORDINATE_FRAME_FULL_MATRIX_GEOCENTRIC 1132
+
 #define EPSG_NAME_METHOD_COORDINATE_FRAME_GEOGRAPHIC_2D                        \
     "Coordinate Frame rotation (geog2D domain)"
 #define EPSG_CODE_METHOD_COORDINATE_FRAME_GEOGRAPHIC_2D 9607
 
+#define EPSG_NAME_METHOD_COORDINATE_FRAME_FULL_MATRIX_GEOGRAPHIC_2D            \
+    "Coordinate Frame rotation full matrix (geog2D)"
+#define EPSG_CODE_METHOD_COORDINATE_FRAME_FULL_MATRIX_GEOGRAPHIC_2D 1133
+
+#define EPSG_NAME_METHOD_COORDINATE_FRAME_FULL_MATRIX_GEOGRAPHIC_3D            \
+    "Coordinate Frame rotation full matrix (geog3D)"
+#define EPSG_CODE_METHOD_COORDINATE_FRAME_FULL_MATRIX_GEOGRAPHIC_3D 1140
+
 #define EPSG_NAME_METHOD_COORDINATE_FRAME_GEOGRAPHIC_3D                        \
     "Coordinate Frame rotation (geog3D domain)"
 #define EPSG_CODE_METHOD_COORDINATE_FRAME_GEOGRAPHIC_3D 1038
@@ -595,15 +622,32 @@
     "Point motion by grid (Canada NTv2_Vel)"
 #define EPSG_CODE_METHOD_POINT_MOTION_BY_GRID_CANADA_NTV2_VEL 1070
 
+#define EPSG_NAME_METHOD_POINT_MOTION_BY_GRID_CANADA_NEU_DOMAIN_NTV2_VEL       \
+    "Point motion by grid (NEU domain) (NTv2_Vel)"
+#define EPSG_CODE_METHOD_POINT_MOTION_BY_GRID_CANADA_NEU_DOMAIN_NTV2_VEL 1141
+
 #define EPSG_CODE_PARAMETER_POINT_MOTION_VELOCITY_GRID_FILE 1050
 #define EPSG_NAME_PARAMETER_POINT_MOTION_VELOCITY_GRID_FILE                    \
     "Point motion velocity grid file"
 
 /* ------------------------------------------------------------------------ */
+
+#define EPSG_NAME_METHOD_NEW_ZEALAND_DEFORMATION_MODEL                         \
+    "New Zealand Deformation Model"
+#define EPSG_CODE_METHOD_NEW_ZEALAND_DEFORMATION_MODEL 1079
+
+/* ------------------------------------------------------------------------ */
+
+/* Has been renamed to
+ * EPSG_NAME_METHOD_GEOGRAPHIC3D_OFFSET_BY_VELOCITY_GRID_NTV2_VEL */
 #define EPSG_NAME_METHOD_GEOGRAPHIC3D_OFFSET_BY_VELOCITY_GRID_NRCAN            \
     "Geographic3D Offset by velocity grid (NRCan byn)"
 #define EPSG_CODE_METHOD_GEOGRAPHIC3D_OFFSET_BY_VELOCITY_GRID_NRCAN 1114
 
+#define EPSG_NAME_METHOD_GEOGRAPHIC3D_OFFSET_BY_VELOCITY_GRID_NTV2_VEL         \
+    "Geographic3D Offset by velocity grid (NTv2_Vel)"
+#define EPSG_CODE_METHOD_GEOGRAPHIC3D_OFFSET_BY_VELOCITY_GRID_NTV2_VEL 1114
+
 /* ------------------------------------------------------------------------ */
 
 #define EPSG_NAME_METHOD_VERTICAL_OFFSET_BY_VELOCITY_GRID_NRCAN                \
@@ -612,6 +656,16 @@
 
 /* ------------------------------------------------------------------------ */
 
+#define EPSG_NAME_METHOD_GEOGRAPHIC3D_TO_GRAVITYRELATEDHEIGHT                  \
+    "Geographic3D to GravityRelatedHeight"
+#define EPSG_CODE_METHOD_GEOGRAPHIC3D_TO_GRAVITYRELATEDHEIGHT 1136
+
+#define EPSG_NAME_METHOD_GEOGRAPHIC3D_TO_GEOG2D_GRAVITYRELATEDHEIGHT           \
+    "Geog3D to Geog2D+GravityRelatedHeight"
+#define EPSG_CODE_METHOD_GEOGRAPHIC3D_TO_GEOG2D_GRAVITYRELATEDHEIGHT 1131
+
+/* ------------------------------------------------------------------------ */
+
 #define PROJ_WKT2_NAME_METHOD_HEIGHT_TO_GEOG3D                                 \
     "GravityRelatedHeight to Geographic3D"
 
@@ -643,6 +697,14 @@
 #define EPSG_NAME_METHOD_VERTICALGRID_GTX                                      \
     "Vertical Offset by Grid Interpolation (gtx)"
 
+#define EPSG_CODE_METHOD_VERTICALGRID_ASC 1085
+#define EPSG_NAME_METHOD_VERTICALGRID_ASC                                      \
+    "Vertical Offset by Grid Interpolation (asc)"
+
+#define EPSG_CODE_METHOD_VERTICALGRID_GTG 1129
+#define EPSG_NAME_METHOD_VERTICALGRID_GTG                                      \
+    "Vertical Offset by Grid Interpolation (gtg)"
+
 #define EPSG_CODE_METHOD_VERTICALGRID_PL_TXT 1101
 #define EPSG_NAME_METHOD_VERTICALGRID_PL_TXT                                   \
     "Vertical Offset by Grid Interpolation (PL txt)"
@@ -688,6 +750,21 @@
 
 /* ------------------------------------------------------------------------ */
 
+/* TIN-based transformations */
+
+#define EPSG_NAME_METHOD_VERTICAL_OFFSET_BY_TIN_INTERPOLATION_JSON             \
+    "Vertical Offset by TIN Interpolation (JSON)"
+#define EPSG_CODE_METHOD_VERTICAL_OFFSET_BY_TIN_INTERPOLATION_JSON 1137
+
+#define EPSG_NAME_METHOD_CARTESIAN_GRID_OFFSETS_BY_TIN_INTERPOLATION_JSON      \
+    "Cartesian Grid Offsets by TIN Interpolation (JSON)"
+#define EPSG_CODE_METHOD_CARTESIAN_GRID_OFFSETS_BY_TIN_INTERPOLATION_JSON 1138
+
+#define EPSG_NAME_PARAMETER_TIN_OFFSET_FILE "TIN offset file"
+#define EPSG_CODE_PARAMETER_TIN_OFFSET_FILE 1064
+
+/* ------------------------------------------------------------------------ */
+
 #define EPSG_CODE_METHOD_CHANGE_VERTICAL_UNIT 1069
 #define EPSG_NAME_METHOD_CHANGE_VERTICAL_UNIT "Change of Vertical Unit"
 
@@ -732,6 +809,10 @@
 #define EPSG_NAME_PARAMETER_VERTICAL_OFFSET "Vertical Offset"
 #define EPSG_CODE_PARAMETER_VERTICAL_OFFSET 8603
 
+#define EPSG_NAME_PARAMETER_GEOID_HEIGHT "Geoid height"
+#define EPSG_CODE_PARAMETER_GEOID_HEIGHT 8604
+
+/* Geoid undulation is the name before EPSG v11.023 */
 #define EPSG_NAME_PARAMETER_GEOID_UNDULATION "Geoid undulation"
 #define EPSG_CODE_PARAMETER_GEOID_UNDULATION 8604
 
@@ -806,6 +887,17 @@
 
 /* ------------------------------------------------------------------------ */
 
+#define EPSG_CODE_METHOD_CARTESIAN_GRID_OFFSETS 9656
+#define EPSG_NAME_METHOD_CARTESIAN_GRID_OFFSETS "Cartesian Grid Offsets"
+
+#define EPSG_CODE_PARAMETER_EASTING_OFFSET 8728
+#define EPSG_NAME_PARAMETER_EASTING_OFFSET "Easting offset"
+
+#define EPSG_CODE_PARAMETER_NORTHING_OFFSET 8729
+#define EPSG_NAME_PARAMETER_NORTHING_OFFSET "Northing offset"
+
+/* ------------------------------------------------------------------------ */
+
 #define EPSG_NAME_METHOD_GEOCENTRIC_TOPOCENTRIC                                \
     "Geocentric/topocentric conversions"
 #define EPSG_CODE_METHOD_GEOCENTRIC_TOPOCENTRIC 9836
