@@ -539,35 +539,35 @@ Component Component::parse(const json &j) {
         getOptString(jSpatialModel, "md5_checksum");
 
     const json jTimeFunction = getObjectMember(j, "time_function");
-    const std::string timeFunctionType = getReqString(jTimeFunction, "type");
+    std::string timeFunctionType = getReqString(jTimeFunction, "type");
     const json jParameters = timeFunctionType == "constant"
                                  ? json()
                                  : getObjectMember(jTimeFunction, "parameters");
 
     if (timeFunctionType == "constant") {
         std::unique_ptr<ConstantTimeFunction> tf(new ConstantTimeFunction());
-        tf->type = timeFunctionType;
+        tf->type = std::move(timeFunctionType);
         comp.mTimeFunction = std::move(tf);
     } else if (timeFunctionType == "velocity") {
         std::unique_ptr<VelocityTimeFunction> tf(new VelocityTimeFunction());
-        tf->type = timeFunctionType;
+        tf->type = std::move(timeFunctionType);
         tf->referenceEpoch =
             Epoch(getReqString(jParameters, "reference_epoch"));
         comp.mTimeFunction = std::move(tf);
     } else if (timeFunctionType == "step") {
         std::unique_ptr<StepTimeFunction> tf(new StepTimeFunction());
-        tf->type = timeFunctionType;
+        tf->type = std::move(timeFunctionType);
         tf->stepEpoch = Epoch(getReqString(jParameters, "step_epoch"));
         comp.mTimeFunction = std::move(tf);
     } else if (timeFunctionType == "reverse_step") {
         std::unique_ptr<ReverseStepTimeFunction> tf(
             new ReverseStepTimeFunction());
-        tf->type = timeFunctionType;
+        tf->type = std::move(timeFunctionType);
         tf->stepEpoch = Epoch(getReqString(jParameters, "step_epoch"));
         comp.mTimeFunction = std::move(tf);
     } else if (timeFunctionType == "piecewise") {
         std::unique_ptr<PiecewiseTimeFunction> tf(new PiecewiseTimeFunction());
-        tf->type = timeFunctionType;
+        tf->type = std::move(timeFunctionType);
         tf->beforeFirst = getReqString(jParameters, "before_first");
         if (tf->beforeFirst != "zero" && tf->beforeFirst != "constant" &&
             tf->beforeFirst != "linear") {
@@ -593,7 +593,7 @@ Component Component::parse(const json &j) {
     } else if (timeFunctionType == "exponential") {
         std::unique_ptr<ExponentialTimeFunction> tf(
             new ExponentialTimeFunction());
-        tf->type = timeFunctionType;
+        tf->type = std::move(timeFunctionType);
         tf->referenceEpoch =
             Epoch(getReqString(jParameters, "reference_epoch"));
         tf->endEpoch = Epoch(getOptString(jParameters, "end_epoch"));
